From c93c6e706021b7405d465047757f11f65c63008e Mon Sep 17 00:00:00 2001
From: Caroline Ruffel <caroline.ruffel@c-s.fr>
Date: Thu, 20 Apr 2006 09:38:18 +0000
Subject: [PATCH] nomsg

---
 Code/FeatureExtraction/otbLineRatioDetector.h | 22 +++++++++----------
 .../otbLineRatioDetector.txx                  | 20 ++++++++---------
 2 files changed, 21 insertions(+), 21 deletions(-)

diff --git a/Code/FeatureExtraction/otbLineRatioDetector.txx b/Code/FeatureExtraction/otbLineRatioDetector.txx
index ef88dbc96d..c938aefeab 100755
--- a/Code/FeatureExtraction/otbLineRatioDetector.txx
+++ b/Code/FeatureExtraction/otbLineRatioDetector.txx
@@ -8,10 +8,10 @@
   $Id$ 
 
 =========================================================================*/
-#ifndef __otbLineRatioDetector_txx
-#define __otbLineRatioDetector_txx
+#ifndef __otbLineRatioDetectorImageFilter_txx
+#define __otbLineRatioDetectorImageFilter_txx
 
-#include "otbLineRatioDetector.h"
+#include "otbLineRatioDetectorImageFilter.h"
 
 #include "itkDataObject.h"
 #include "itkExceptionObject.h"
@@ -32,7 +32,7 @@ namespace otb
  *
  */
 template <class TInputImage, class TOutputImage, class InterpolatorType >
-LineRatioDetector<TInputImage, TOutputImage, InterpolatorType>::LineRatioDetector()
+LineRatioDetectorImageFilter<TInputImage, TOutputImage, InterpolatorType>::LineRatioDetectorImageFilter()
 {
   m_Radius.Fill(1);
   m_LengthLine = 1;
@@ -42,7 +42,7 @@ LineRatioDetector<TInputImage, TOutputImage, InterpolatorType>::LineRatioDetecto
 }
 
 template <class TInputImage, class TOutputImage, class InterpolatorType>
-void LineRatioDetector<TInputImage, TOutputImage, InterpolatorType>::GenerateInputRequestedRegion() throw (itk::InvalidRequestedRegionError)
+void LineRatioDetectorImageFilter<TInputImage, TOutputImage, InterpolatorType>::GenerateInputRequestedRegion() throw (itk::InvalidRequestedRegionError)
 {
   // call the superclass' implementation of this method
   Superclass::GenerateInputRequestedRegion();
@@ -105,7 +105,7 @@ void LineRatioDetector<TInputImage, TOutputImage, InterpolatorType>::GenerateInp
  */
 template <class TInputImage, class TOutputImage, class InterpolatorType>
 void 
-LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>
+LineRatioDetectorImageFilter< TInputImage, TOutputImage, InterpolatorType>
 ::BeforeThreadedGenerateData()
 {
 
@@ -124,8 +124,8 @@ LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>
 }
 
 template <class TInputImage, class TOutputImage, class InterpolatorType>
-const typename LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>::OutputImageType *
-LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>
+const typename LineRatioDetectorImageFilter< TInputImage, TOutputImage, InterpolatorType>::OutputImageType *
+LineRatioDetectorImageFilter< TInputImage, TOutputImage, InterpolatorType>
 ::GetOutputDirection()
 {
 	this->Update();
@@ -133,7 +133,7 @@ LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>
 }
 
 template< class TInputImage, class TOutputImage, class InterpolatorType>
-void LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>
+void LineRatioDetectorImageFilter< TInputImage, TOutputImage, InterpolatorType>
 ::ThreadedGenerateData(	
 			const 	OutputImageRegionType& 		outputRegionForThread,
                        	int 	threadId
@@ -365,7 +365,7 @@ void LineRatioDetector< TInputImage, TOutputImage, InterpolatorType>
  */
 template <class TInputImage, class TOutput, class InterpolatorType>
 void 
-LineRatioDetector<TInputImage, TOutput, InterpolatorType>::PrintSelf(std::ostream& os, itk::Indent indent) const
+LineRatioDetectorImageFilter<TInputImage, TOutput, InterpolatorType>::PrintSelf(std::ostream& os, itk::Indent indent) const
 {
   Superclass::PrintSelf( os, indent );
   os << indent << "Length: " << m_LengthLine << std::endl;
diff --git a/Code/FeatureExtraction/otbLineRatioDetector.h b/Code/FeatureExtraction/otbLineRatioDetector.h
index 1e82ca4f2d..c4e4194401 100755
--- a/Code/FeatureExtraction/otbLineRatioDetector.h
+++ b/Code/FeatureExtraction/otbLineRatioDetector.h
@@ -8,8 +8,8 @@
   $Id$ 
 
 =========================================================================*/
-#ifndef __otbLineRatioDetector_h
-#define __otbLineRatioDetector_h
+#ifndef __otbLineRatioDetectorImageFilter_h
+#define __otbLineRatioDetectorImageFilter_h
 
 #include "itkBSplineInterpolateImageFunction.h"
 #include "itkImageToImageFilter.h"
@@ -26,7 +26,7 @@
 namespace otb
 {
 
-/** \class LineRatioDetector
+/** \class LineRatioDetectorImageFilter
  * \brief Application of the filter of detection of linear features 
  *
  * This class implements the Tupin's detector D1 used to detect 
@@ -64,7 +64,7 @@ namespace otb
 template <class TInputImage, 
 	  class TOutputImage,
 	  class InterpolatorType = itk::BSplineInterpolateImageFunction<TInputImage> >
-class ITK_EXPORT LineRatioDetector :  public itk::ImageToImageFilter< TInputImage, TOutputImage >
+class ITK_EXPORT LineRatioDetectorImageFilter :  public itk::ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** 	Extract dimensions as well of the images of entry of exit. */
@@ -79,7 +79,7 @@ public:
   typedef TOutputImage OutputImageType;
 
   /** typedef for the classes standards. */
-  typedef LineRatioDetector Self;
+  typedef LineRatioDetectorImageFilter Self;
   typedef itk::ImageToImageFilter< InputImageType, OutputImageType> Superclass;
   typedef itk::SmartPointer<Self> Pointer;
   typedef itk::SmartPointer<const Self>  ConstPointer;
@@ -88,7 +88,7 @@ public:
   itkNewMacro(Self);
 
   /** Return the name of the class. */
-  itkTypeMacro(LineRatioDetector, itk::ImageToImageFilter);
+  itkTypeMacro(LineRatioDetectorImageFilter, itk::ImageToImageFilter);
 
   /** Typedefs to describe and access Interpolator */
   typedef typename InterpolatorType::Pointer InterpolatorPointer;
@@ -132,13 +132,13 @@ public:
   const OutputImageType * GetOutputDirection();
 
 protected:
-  LineRatioDetector();
-  virtual ~LineRatioDetector() {};
+  LineRatioDetectorImageFilter();
+  virtual ~LineRatioDetectorImageFilter() {};
   void PrintSelf(std::ostream& os, itk::Indent indent) const;
 
   void BeforeThreadedGenerateData();
 
   /** LineRatioDetector can be implemented for a treatment of filter multithreaded. 
    * Thus, the ThreadedGenerateData() method is called for each thread process. 
    * The data image are allocated automatically by the mother class by calling the 
    * ThreadedGenerateData() method. ThreadedGenerateData can only write the portion 
@@ -150,7 +150,7 @@ protected:
                             int threadId );
 
 private:
-  LineRatioDetector(const Self&); //purposely not implemented
+  LineRatioDetectorImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
  
   /** Length of the linear feature = 2*m_LengthLine+1 */ 
@@ -173,7 +173,7 @@ private:
 } // end namespace otb
 
 #ifndef OTB_MANUAL_INSTANTIATION
-#include "otbLineRatioDetector.txx"
+#include "otbLineRatioDetectorImageFilter.txx"
 #endif
 
   
@@ -132,13 +132,13 @@ public:
   void BeforeThreadedGenerateData();
 
-  /** LineRatioDetector can be implemented for a treatment of filter multithreaded. 
+  /** LineRatioDetectorImageFilter can be implemented for a treatment of filter multithreaded. 
    * Thus, the ThreadedGenerateData() method is called for each thread process. 
    * The data image are allocated automatically by the mother class by calling the 
-- 
GitLab